"""
This module is used to loop print out the content in list
"""
def print_lol(the_list):
	for each_item in the_list:
		if isinstance(each_item,list):
			print_lol(each_item);
		else:
			print(each_item);




from distutils.core import setup

setup(
	name         = 'mi_nester',
	version      = '1.2.0',
	py_modules   = ['mi_nester'],
	author       = 'miki',
	author_email = 'fangyu1313@gmail.com',
	url          = 'https://pypi.python.org/pypi?%3Aaction=pkg_edit&name=mi_nester',
	description  = 'A simple',
)